@@ -33,10 +33,24 @@ GenOO::Region - Role that represents a region on a reference sequence
 # Let the code begin...
 
 package GenOO::Region;
+$GenOO::Region::VERSION = '1.4.4';
+
+#######################################################################
+#######################   Load External modules   #####################
+#######################################################################
+use Modern::Perl;
 use Moose::Role;
 
+
+#######################################################################
+#######################   Required attributes   #######################
+#######################################################################
 requires qw(strand rname start stop copy_number);
 
+
+#######################################################################
+#######################   Interface attributes   ######################
+#######################################################################
 has 'length' => (
 	is        => 'ro',
 	builder   => '_calculate_length',
@@ -44,6 +58,7 @@ has 'length' => (
 	lazy      => 1,
 );
 
+
 #######################################################################
 ########################   Interface Methods   ########################
 #######################################################################
